@@ -23,6 +23,8 @@ class NewsAppCache(BaseAppCache):
             urls.append(reverse('news_detail', kwargs={'pk': item.pk}))
             # Adding this to later remove it in get_network
             urls.append(reverse('news_detail_live', kwargs={'pk': item.pk}))
+        urls.append("http://www.example.com/fake-urlake"
+                    "/")
         return urls
 
     def signal_connector(self, instance, **kwargs):
